@@ -1,7 +1,7 @@
 package Mojo::Webqq;
 use strict;
 use Carp ();
-$Mojo::Webqq::VERSION = "1.8.5";
+$Mojo::Webqq::VERSION = "1.8.6";
 use base qw(Mojo::Base);
 use Mojo::Webqq::Log;
 use Mojo::Webqq::Cache;
@@ -15,7 +15,7 @@ use base qw(Mojo::EventEmitter Mojo::Webqq::Base Mojo::Webqq::Model Mojo::Webqq:
 has qq                  => undef;
 has pwd                 => undef;
 has security            => 0;
-has state               => 'online';   #online|away|busy|silent|hidden|offline,
+has state               => 'online';   #online|away|busy|silent|hidden|offline|callme,
 has type                => 'smartqq';  #smartqq
 has login_type          => 'qrlogin';    #qrlogin|login
 has ua_debug            => 0;
